diff libpurple/protocols/bonjour/jabber.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 61005dea822b
line wrap: on
line diff
--- a/libpurple/protocols/bonjour/jabber.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/bonjour/jabber.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file jabber.h The Gaim interface to mDNS and peer to peer Jabber.
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -36,7 +36,7 @@
 	gint port;
 	gint socket;
 	gint watcher_id;
-	GaimAccount* account;
+	PurpleAccount* account;
 } BonjourJabber;
 
 typedef struct _BonjourJabberConversation
@@ -58,7 +58,7 @@
 
 int bonjour_jabber_send_message(BonjourJabber *data, const gchar *to, const gchar *body);
 
-void bonjour_jabber_close_conversation(BonjourJabber *data, GaimBuddy *gb);
+void bonjour_jabber_close_conversation(BonjourJabber *data, PurpleBuddy *gb);
 
 void bonjour_jabber_stop(BonjourJabber *data);
@@ -1,9 +1,9 @@
 /**
- * @file jabber.h The Gaim interface to mDNS and peer to peer Jabber.
+ * @file jabber.h The Purple interface to mDNS and peer to peer Jabber.
  *
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.